@@ -2,18 +2,15 @@ package call
 
 import (
 	"context"
-	"os"
 	"os/exec"
 	"strings"
 
 	"github.com/jonaslu/ain/internal/pkg/data"
 	"github.com/jonaslu/ain/internal/pkg/utils"
-	"github.com/pkg/errors"
 )
 
 type httpie struct {
 	backendInput *data.BackendInput
-	tmpFileName  string
 	binaryName   string
 }
 
@@ -46,17 +43,15 @@ func (httpie *httpie) getMethodArgument() string {
 	return strings.ToUpper(httpie.backendInput.Method)
 }
 
-func (httpie *httpie) getBodyArgument(tmpDir string) (string, error) {
-	tmpFile, err := httpie.backendInput.GetBodyAsTempFile(tmpDir)
-	if err != nil {
-		return "", err
+func (httpie *httpie) getBodyArgument() []string {
+	if httpie.backendInput.TempFileName != "" {
+		return []string{"@" + httpie.backendInput.TempFileName}
 	}
 
-	httpie.tmpFileName = tmpFile.Name()
-	return "@" + tmpFile.Name(), nil
+	return []string{}
 }
 
-func (httpie *httpie) runAsCmd(ctx context.Context) ([]byte, error) {
+func (httpie *httpie) getAsCmd(ctx context.Context) *exec.Cmd {
 	args := []string{}
 	for _, backendOpt := range httpie.backendInput.BackendOptions {
 		args = append(args, backendOpt...)
@@ -68,31 +63,13 @@ func (httpie *httpie) runAsCmd(ctx context.Context) ([]byte, error) {
 
 	args = append(args, httpie.backendInput.Host.String())
 	args = append(args, httpie.backendInput.Headers...)
-
-	if len(httpie.backendInput.Body) > 0 {
-		bodyArg, err := httpie.getBodyArgument("")
-
-		if err != nil {
-			return nil, err
-		}
-
-		args = append(args, bodyArg)
-	}
+	args = append(args, httpie.getBodyArgument()...)
 
 	httpCmd := exec.CommandContext(ctx, httpie.binaryName, args...)
-	output, err := httpCmd.CombinedOutput()
-
-	if err != nil {
-		return output, &BackedErr{
-			Err:      err,
-			ExitCode: httpCmd.ProcessState.ExitCode(),
-		}
-	}
-
-	return output, nil
+	return httpCmd
 }
 
-func (httpie *httpie) getAsString() (string, error) {
+func (httpie *httpie) getAsString() string {
 	args := [][]string{}
 	for _, optionLine := range httpie.backendInput.BackendOptions {
 		lineArguments := []string{}
@@ -112,29 +89,9 @@ func (httpie *httpie) getAsString() (string, error) {
 		args = append(args, []string{utils.EscapeForShell(header)})
 	}
 
-	if len(httpie.backendInput.Body) > 0 {
-		cwd, err := os.Getwd()
-		if err != nil {
-			return "", errors.Wrap(err, "Could not get current working dir, cannot store body temp-file")
-		}
-
-		bodyArg, err := httpie.getBodyArgument(cwd)
-		if err != nil {
-			return "", err
-		}
-
-		args = append(args, []string{bodyArg})
-	}
+	args = append(args, httpie.getBodyArgument())
 
 	output := httpie.binaryName + " " + utils.PrettyPrintStringsForShell(args)
 
-	return output, nil
-}
-
-func (httpie *httpie) cleanUp() error {
-	if httpie.tmpFileName != "" {
-		return os.Remove(httpie.tmpFileName)
-	}
-
-	return nil
+	return output
 }
