@@ -23,6 +23,17 @@ type BackendInput struct {
 
 	Backend        string
 	BackendOptions [][]string
+
+	PrintCommand  bool
+	LeaveTempFile bool
+
+	TempFileName string
 }
 
 type TimeoutContextValueKey struct{}
+
+type BackendOutput struct {
+	Stderr   string
+	Stdout   string
+	ExitCode int
+}
