@@ -1,7 +1,6 @@
 package disk
 
 import (
-	"flag"
 	"fmt"
 	"os"
 	"os/exec"
@@ -77,13 +76,7 @@ func getPresentBackendBinaries() ([]string, []string) {
 	return presentBackends, usefulBackendOptions
 }
 
-func GenerateEmptyTemplates() error {
-	var templateFileNames []string
-
-	if len(flag.Args()) >= 1 {
-		templateFileNames = flag.Args()
-	}
-
+func GenerateEmptyTemplates(templateFileNames []string) error {
 	presentBackends, usefulBackendOptions := getPresentBackendBinaries()
 	if len(presentBackends) == 0 {
 		presentBackends = []string{`# No backend binaries found, please install at least one.
@@ -117,13 +110,13 @@ func GenerateEmptyTemplates() error {
 		_, err := os.Stat(filename)
 
 		if !os.IsNotExist(err) {
-			return errors.Errorf("Cannot write basic template. File already exists %s", filename)
+			return errors.Errorf("cannot write basic template. File already exists %s", filename)
 		}
 
 		err = os.WriteFile(filename, []byte(starterTemplate), 0644)
 
 		if err != nil {
-			return errors.Wrapf(err, "Could not write basic template to file %s", filename)
+			return errors.Wrapf(err, "could not write basic template to file %s", filename)
 		}
 	}
 
