@@ -15,22 +15,22 @@ func (s *sectionedTemplate) getBackend() string {
 	}
 
 	if len(backendSourceMarkers) > 1 {
-		s.setFatalMessage("Found several lines under [Backend]", backendSourceMarkers[0].SourceLineIndex)
+		s.setFatalMessage("Found several lines under [Backend]", backendSourceMarkers[0].sourceLineIndex)
 		return ""
 	}
 
 	backendSourceMarker := backendSourceMarkers[0]
-	backend := strings.ToLower(backendSourceMarker.LineContents)
+	backend := strings.ToLower(backendSourceMarker.lineContents)
 
 	if !call.ValidBackend(backend) {
 		for backendName := range call.ValidBackends {
 			if utils.LevenshteinDistance(backend, backendName) < 3 {
-				s.setFatalMessage(fmt.Sprintf("Unknown backend: %s. Did you mean %s", backend, backendName), backendSourceMarker.SourceLineIndex)
+				s.setFatalMessage(fmt.Sprintf("Unknown backend: %s. Did you mean %s", backend, backendName), backendSourceMarker.sourceLineIndex)
 				return ""
 			}
 		}
 
-		s.setFatalMessage(fmt.Sprintf("Unknown backend %s", backend), backendSourceMarker.SourceLineIndex)
+		s.setFatalMessage(fmt.Sprintf("Unknown backend %s", backend), backendSourceMarker.sourceLineIndex)
 		return ""
 	}
 
