@@ -10,10 +10,10 @@ func (s *sectionedTemplate) getBackendOptions() [][]string {
 	var backendOptions [][]string
 
 	for _, backedOptionSourceMarker := range *s.getNamedSection(backendOptionsSection) {
-		tokenizedBackendOpts, err := utils.TokenizeLine(backedOptionSourceMarker.LineContents)
+		tokenizedBackendOpts, err := utils.TokenizeLine(backedOptionSourceMarker.lineContents)
 		if err != nil {
 			// !! TODO !! Can parse all messages don't have to return
-			s.setFatalMessage(fmt.Sprintf("Could not parse backend-option %s", err.Error()), backedOptionSourceMarker.SourceLineIndex)
+			s.setFatalMessage(fmt.Sprintf("Could not parse backend-option %s", err.Error()), backedOptionSourceMarker.sourceLineIndex)
 			return backendOptions
 		}
 
