@@ -3,7 +3,7 @@ package parse
 func (s *sectionedTemplate) getHost() string {
 	var host string
 	for _, hostSourceMarker := range *s.getNamedSection(hostSection) {
-		host = host + hostSourceMarker.LineContents
+		host = host + hostSourceMarker.lineContents
 	}
 
 	return host
